function C3515 = gsw_C3515

% gsw_C3515                        Conductivity of SSW at SP=35,t_68=15,p=0
%==========================================================================
%
% USAGE:
%  C3515 = gsw_C3515
%
% DESCRIPTION:
%  This function provides the present estimate of Conductivity, C, of 
%  Standard Seawater (SSW) at (SP=35, t_68=15, p=0) which is 
%  42.9140 mS/cm (=4.29140 S/m) (Culkin and Smith, 1980; UNESCO, 1983).  
%
% OUTPUT:
%  C3515  =  Conductivity at (SP=35, t_68=15, p=0)                [ mS/cm ]
%
% AUTHOR: 
%  Trevor McDougall and Paul Barker                    [ help@teos-10.org ]
%
% VERSION NUMBER: 3.06.12 (25th May, 2020)
%
% REFERENCES:
%  Culkin and Smith, 1980:  Determination of the Concentration of Potassium  
%   Chloride Solution Having the Same Electrical Conductivity, at 15C and 
%   Infinite Frequency, as Standard Seawater of Salinity 35.0000 
%   (Chlorinity 19.37394), IEEE J. Oceanic Eng, 5, 22-23.
%
%  Unesco, 1983: Algorithms for computation of fundamental properties of 
%   seawater. Unesco Technical Papers in Marine Science, 44, 53 pp.
%
%  The software is available from http://www.TEOS-10.org
%
%==========================================================================

C3515 = 42.9140;

end
